plissken
===============================================


.. image:: https://gitlab.com/dylanbstorey/plissken/badges/master/pipeline.svg
    :target: https://gitlab.com/dylanbstorey/plissken/commits/master

.. image:: https://gitlab.com/dylanbstorey/plissken/badges/master/coverage.svg
    :target: https://gitlab.com/dylanbstorey/plissken/commits/master

.. image:: https://badge.fury.io/py/plissken.svg
    :target: https://badge.fury.io/py/plissken



plissken is going to be the next big thing !


Installation :

.. code-block:: bash

    pip install plissken
